(v0.4.0)=
### 0.4.0 {small}`2017-12-23`

- export to [SPRING] {cite:p}`Weinreb2017` for interactive visualization of data:
  [spring tutorial] {smaller}`S Wollock`

[spring]: https://github.com/AllonKleinLab/SPRING/
[spring tutorial]: https://github.com/scverse/scanpy_usage/tree/master/171111_SPRING_export
